{{/*
Expand the name of the chart.
*/}}
{{- define "demo-chart.name" -}}
{{- default .Chart.Name .Values.nameOverride | trunc 63 | trimSuffix "-" }}
{{- end }}

{{/*
Create a default fully qualified app name.
We truncate at 63 chars because some Kubernetes name fields are limited to this (by the DNS naming spec).
If release name contains chart name it will be used as a full name.
*/}}
{{- define "demo-chart.fullname" -}}
{{- if .Values.fullnameOverride }}
{{- .Values.fullnameOverride | trunc 63 | trimSuffix "-" }}
{{- else }}
{{- $name := default .Chart.Name .Values.nameOverride }}
{{- if contains $name .Release.Name }}
{{- .Release.Name | trunc 63 | trimSuffix "-" }}
{{- else }}
{{- printf "%s-%s" .Release.Name $name | trunc 63 | trimSuffix "-" }}
{{- end }}
{{- end }}
{{- end }}

{{/*
Create chart name and version as used by the chart label.
*/}}
{{- define "demo-chart.chart" -}}
{{- printf "%s-%s" .Chart.Name .Chart.Version | replace "+" "_" | trunc 63 | trimSuffix "-" }}
{{- end }}

{{/*
Common labels
*/}}
{{- define "demo-chart.labels" -}}
helm.sh/chart: {{ include "demo-chart.chart" . }}
{{ include "demo-chart.selectorLabels" . }}
{{- if .Chart.AppVersion }}
app.kubernetes.io/version: {{ .Chart.AppVersion | quote }}
{{- end }}
app.kubernetes.io/managed-by: {{ .Release.Service }}
{{- end }}

{{/*
Selector labels
*/}}
{{- define "demo-chart.selectorLabels" -}}
app.kubernetes.io/name: {{ include "demo-chart.name" . }}
app.kubernetes.io/instance: {{ .Release.Name }}
{{- end }}

{{/*
Create the name of the service account to use
*/}}
{{- define "demo-chart.serviceAccountName" -}}
{{- if .Values.serviceAccount.create }}
{{- default (include "demo-chart.fullname" .) .Values.serviceAccount.name }}
{{- else }}
{{- default "default" .Values.serviceAccount.name }}
{{- end }}
{{- end }}

{{/*
Create the url path of service
*/}}
{{- define "demo-chart.path" -}}
{{ .Values.pathPrefix }}/{{ .Release.Name }}
{{- end }}

{{/*
Create the GPUNodeAffinity of service
*/}}
{{- define "demo-chart.GPUNodeAffinity" -}}
{{- if .Values.gpuResource.enable -}}
nodeAffinity:
  requiredDuringSchedulingIgnoredDuringExecution:
    nodeSelectorTerms:
    - matchExpressions:
      - key: gpushare
        operator: In
        values: ["true"]
{{- if .Values.gpuResource.type }}
      - key: gputype
        operator: In
        values:
        {{- range .Values.gpuResource.type }}
        - {{ . | upper }}
        {{- end }}
{{- end }}
{{- if .Values.gpuResource.driverVersion }}
      - key: gpudrive
        operator: In
        values:
        {{- range .Values.gpuResource.driverVersion }}
        - {{ . | quote }}
        {{- end }}
{{- end }}
{{- else -}}
nodeAffinity:
  preferredDuringSchedulingIgnoredDuringExecution:
  - preference:
      matchExpressions:
      - key: gpushare
        operator: NotIn
        values: ["true"]
    weight: 100
{{- end }}
{{- end }}